@@ -19,8 +19,8 @@ import gdb
 import os
 import os.path
 
-pythondir = '/opt/share/gcc-15.1.0/python'
-libdir = '/opt/lib/gcc/x86_64-w64-mingw32ucrt/15.1.0'
+pythondir = '/opt/share/gcc-15.2.0/python'
+libdir = '/opt/lib/gcc/x86_64-w64-mingw32ucrt/15.2.0'
 
 # This file might be loaded when there is no current objfile.  This
 # can happen if the user loads it manually.  In this case we don't
@@ -55,10 +55,14 @@ if gdb.current_objfile () is not None:
     if not dir_ in sys.path:
         sys.path.insert(0, dir_)
 
-    gdb.execute('skip -rfu ^std::(move|forward|as_const|(__)?addressof)')
-    gdb.execute('skip -rfu ^std::(shared|unique)_ptr<.*>::(get|operator)')
-    gdb.execute('skip -rfu ^std::(basic_string|vector|array|deque|(forward_)?list|(unordered_|flat_)?(multi)?(map|set)|span)<.*>::(c?r?(begin|end)|front|back|data|size|empty)')
-    gdb.execute('skip -rfu ^std::(basic_string|vector|array|deque|span)<.*>::operator.]')
+    gdb.execute('skip -rfu ^std::(move|forward|as_const|(__)?addressof)',
+                to_string=True)
+    gdb.execute('skip -rfu ^std::(shared|unique)_ptr<.*>::(get|operator)',
+                to_string=True)
+    gdb.execute('skip -rfu ^std::(basic_string|vector|array|deque|(forward_)?list|(unordered_|flat_)?(multi)?(map|set)|span)<.*>::(c?r?(begin|end)|front|back|data|size|empty)',
+                to_string=True)
+    gdb.execute('skip -rfu ^std::(basic_string|vector|array|deque|span)<.*>::operator.]',
+                to_string=True)
 
 # Call a function as a plain import would not execute body of the included file
 # on repeated reloads of this object file.
